| Title: | Shiny App to Find Campgrounds |
|---|---|
| Description: | A Shiny app to find campgrounds. |
| Authors: | Steven E. Pav [aut, cre] (ORCID: <https://orcid.org/0000-0002-4197-6195>) |
| Maintainer: | Steven E. Pav <[email protected]> |
| License: | LGPL-3 |
| Version: | 0.0.0.0005 |
| Built: | 2026-05-08 06:24:37 UTC |
| Source: | https://github.com/shabbychef/HappyCampR |
A shiny app to locate campgrounds.
campr_app( init_lat = 37.7749, init_lon = -122.4194, init_search = "San Francisco" )campr_app( init_lat = 37.7749, init_lon = -122.4194, init_search = "San Francisco" )
init_lat |
an initial latitude to seed the search. |
init_lon |
an initial longitude to seed the search. The default values are for San Francisco. |
init_search |
an initial string to put into the search text. |
a shiny app.
Steven E. Pav [email protected]
Steven E. Pav [email protected]
## Not run: campr_app() ## End(Not run)## Not run: campr_app() ## End(Not run)
Shiny App to Find Campgrounds
HappyCampR is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
This package is maintained as a hobby.
Steven E. Pav [email protected]
News for package ‘HappyCampR’
first CRAN release.
Campground data as a data frame.
data(MoreCamp)data(MoreCamp)
A data.frame object with 13,011 rows and over 20 columns,
each row respresenting a campground in the US or Canada.
The data are taken from USA Campgrounds Info.
The columns are defined as follows:
lonThe longitude of the campground, a double roughly in the range of -160 to -50.
latThe latitude of the campground, a double roughly in the range of 0 to 70.
campground_codeThe upstream ID of the campground, a short character string.
campground_nameThe name the campground, a string.
typeThe type of the campground, a short string. The types
are encoded as follows:
NF for “National Forest” (approximately 3800 rows),
CP for “City/County/Regional Park” (around 3000 rows),
SP for “State Park” (around 1700 rows),
COE for “US Corps of Engineers” (around 800 rows),
PP for “Canadian Provincial Park” (around 800 rows),
SF for “State Forest” (around 700 rows),
BLM for “Bureau of Land Management” (around 400 rows),
NP for “National Park” (around 300 rows),
SFW for “State Fish and Wildlife” (around 250 rows),
SRA for “State Recreation Area” (around 250 rows),
MIL for “Military” (around 200 rows),
UTIL for “Utility” (around 130 rows),
AUTH for “Authority” (around 90 rows),
CNP for “Canadian National Park” (around 80 rows),
SPR for “State Preserve” (around 40 rows),
NRA for “Nanadian National Park” (around 80 rows),
BOR for “Bureau of Reclamation” (around 40 rows),
RES for “Native American Reservation” (around 30 rows),
NM for “National Monument” (around 20 rows),
TVA for “Tennessee Valley Authority” (around 21 rows),
SB for “State Beach” (around 15 rows),
USFW for “US Fish and Wildlife”,
AMCW for “US Fish and Wildlife”,
a few others, probably miscoded, and
around 130 NA.
phone_numberThe phone number, as a string.
dates_openThe published dates open, as a string.
commentsThe published comments, as a string.
num_campsiteThe number of campsites, an integer.
amenitiesThe published amenities, as a string. This is interpreted as a few other columns that appear later.
stateThe US state, or Canadian Province, as a two character string.
bearing_to_townThe compass bearing to the nearest town.
nearest_townThe nearest town, a string.
toiletsA string describing the type of toilets, one of
“vault”,
“pit”,
“flush”
“none”
“flush_and_vault”
or NA.
drinking_waterWhether drinking water is available, a boolean.
reservationsWhether reservations can be made at the campground, a boolean.
showersWhether showers are available at the campground, a boolean.
petsWhether pets are acceptable at the campground, a boolean.
opening_weekThe approximate week number (in the range 1 to
52), when the campground opens, as interpreted from the dates_open
field.
closing_weekThe approximate week number (in the range 1 to
52), when the campground closes, as interpreted from the dates_open
field.
elevation_mThe elevation of the campground, in meters.
distance_to_town_kmThe distance to the nearest town, in kilometers.
Steven E. Pav [email protected]
USA Campgrounds Info, compiled by Tom Hillegass, http://www.uscampgrounds.info/.
## Not run: data(MoreCamp) ## End(Not run)## Not run: data(MoreCamp) ## End(Not run)